@@ -401,7 +401,7 @@ ggv_sidebar_update_coordinates(GgvSidebar *sidebar, gfloat xcoord, gfloat ycoord
 		clabel = g_strdup_printf("%.2f , %.2f",
 								 xcoord*ggv_unit_factors[ggv_unit_index],
 								 ycoord*ggv_unit_factors[ggv_unit_index]);
-		gtk_entry_set_text(GTK_LABEL(sidebar->priv->coordinates), clabel);
+		gtk_entry_set_text(GTK_ENTRY(sidebar->priv->coordinates), clabel);
 		g_free(clabel);
 	}
 }
