@@ -308,10 +308,10 @@ GtkWidget *
 ggv_prefs_dialog_new()
 {
         static const gchar *tbstyle_labels[] = {
-                N_("Use GNOME defaults"),
-                N_("Show both icons and text"),
-                N_("Show only icons"),
-                N_("Show only text")
+                N_("_Use GNOME defaults"),
+                N_("Show _both icons and text"),
+                N_("Show only _icons"),
+                N_("Show only t_ext")
         };
 
         GgvPrefsDialog *dlg;
@@ -386,7 +386,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(10, 2, FALSE);
 
         /* zoom choice menu */
-        label = gtk_label_new(_("Default Zoom:"));
+        label = gtk_label_new_with_mnemonic(_("_Default Zoom:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
@@ -418,9 +418,10 @@ ggv_prefs_dialog_new()
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->zoom);
 
         /* auto-fit choice menu */
-        label = gtk_label_new(_("Auto-fit mode:"));
+        label = gtk_label_new_with_mnemonic(_("A_uto-fit mode:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
@@ -449,9 +450,10 @@ ggv_prefs_dialog_new()
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->auto_fit);
 
         /* units choice menu */
-        label = gtk_label_new(_("Coordinate units:"));
+       label = gtk_label_new_with_mnemonic(_("_Coordinate units:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
@@ -480,9 +482,10 @@ ggv_prefs_dialog_new()
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->units);
 
         /* size choice menu */
-        label = gtk_label_new(_("Fallback page size:"));
+        label = gtk_label_new_with_mnemonic(_("_Fallback page size:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
         gtk_table_attach(GTK_TABLE(table), label,
@@ -510,9 +513,10 @@ ggv_prefs_dialog_new()
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->size);
 
         /* override media size */
-        dlg->override_size = gtk_check_button_new_with_label(_("Override document size"));
+        dlg->override_size = gtk_check_button_new_with_mnemonic (_("Override _document size"));
         gtk_table_attach(GTK_TABLE(table), dlg->override_size,
                          0, 2, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -523,7 +527,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->override_size);
 
         /* orientation choice menu */
-        label = gtk_label_new(_("Fallback media orientation:"));
+        label = gtk_label_new_with_mnemonic(_("Fallback _media orientation:"));
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 5, 6,
@@ -546,13 +550,14 @@ ggv_prefs_dialog_new()
         gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->orientation), menu);
 
         gtk_table_attach(GTK_TABLE(table), dlg->orientation,
-                         1, 2, 4, 5,
+                         1, 2, 5, 6,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL (label), dlg->orientation);
 
         /* override orientation media */
-        dlg->override_orientation = gtk_check_button_new_with_label(_("Override document orientation"));
+        dlg->override_orientation = gtk_check_button_new_with_mnemonic (_("O_verride document orientation"));
         gtk_table_attach(GTK_TABLE(table), dlg->override_orientation,
                          0, 2, 6, 7,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -563,7 +568,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->override_orientation);
 
         /* antialiasing */
-        dlg->aa = gtk_check_button_new_with_label(_("Antialiasing"));
+        dlg->aa = gtk_check_button_new_with_mnemonic (_("A_ntialiasing"));
         gtk_table_attach(GTK_TABLE(table), dlg->aa,
                          0, 2, 7, 8,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -574,7 +579,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->aa);
 
         /* respect EOF */
-        dlg->respect_eof = gtk_check_button_new_with_label(_("Respect EOF comments"));
+        dlg->respect_eof = gtk_check_button_new_with_mnemonic (_("_Respect EOF comments"));
         gtk_table_attach(GTK_TABLE(table), dlg->respect_eof,
                          0, 2, 8, 9,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -585,7 +590,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->respect_eof);
 
         /* watch file */
-        dlg->watch = gtk_check_button_new_with_label(_("Watch file"));
+        dlg->watch = gtk_check_button_new_with_mnemonic (_("_Watch file"));
         gtk_table_attach(GTK_TABLE(table), dlg->watch,
                          0, 2, 9, 10,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -604,7 +609,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(7, 1, FALSE);
 
         /* show side panel */
-        dlg->sidebar = gtk_check_button_new_with_label(_("Show side panel"));
+        dlg->sidebar = gtk_check_button_new_with_mnemonic(_("_Show side panel"));
         gtk_table_attach(GTK_TABLE(table), dlg->sidebar,
                          0, 1, 0, 1,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -614,7 +619,7 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->sidebar);
 
-        dlg->right_panel = gtk_check_button_new_with_label(_("Put side panel in Nautilus on the right"));
+        dlg->right_panel = gtk_check_button_new_with_mnemonic(_("_Put side panel on the right-hand side"));
         gtk_table_attach(GTK_TABLE(table), dlg->right_panel,
                          0, 1, 1, 2,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -625,7 +630,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->right_panel);
 
         /* show menubar */
-        dlg->mbar = gtk_check_button_new_with_label(_("Show menubar"));
+        dlg->mbar = gtk_check_button_new_with_mnemonic(_("Show _menubar"));
         gtk_table_attach(GTK_TABLE(table), dlg->mbar,
                          0, 1, 2, 3,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -635,7 +640,7 @@ ggv_prefs_dialog_new()
                            G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->mbar);
 	/* show toolbar */
-        dlg->toolbar = gtk_check_button_new_with_label(_("Show toolbar"));
+        dlg->toolbar = gtk_check_button_new_with_mnemonic(_("Show _toolbar"));
         gtk_table_attach(GTK_TABLE(table), dlg->toolbar,
                          0, 1, 3, 4,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -657,7 +662,7 @@ ggv_prefs_dialog_new()
                          GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         for(i = 0; i < GGV_TOOLBAR_STYLE_LAST; i++) {
-                dlg->tbstyle[i] = gtk_radio_button_new_with_label(tbstyle_group,
+                dlg->tbstyle[i] = gtk_radio_button_new_with_mnemonic(tbstyle_group,
                                                                   _(tbstyle_labels[i]));
                 tbstyle_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(dlg->tbstyle[i]));
                 g_signal_connect(G_OBJECT(dlg->tbstyle[i]), "toggled",
@@ -668,7 +673,7 @@ ggv_prefs_dialog_new()
         }
                                    
         /* show statusbar */
-        dlg->sbar = gtk_check_button_new_with_label(_("Show statusbar"));
+        dlg->sbar = gtk_check_button_new_with_mnemonic(_("Show statusba_r"));
         gtk_table_attach(GTK_TABLE(table), dlg->sbar,
                          0, 1, 5, 6,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -679,7 +684,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->sbar);
 
         /* save geometry */
-        dlg->savegeo = gtk_check_button_new_with_label(_("Save geometry"));
+        dlg->savegeo = gtk_check_button_new_with_mnemonic(_("Save _geometry"));
         gtk_table_attach(GTK_TABLE(table), dlg->savegeo,
                          0, 1, 6, 7,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -699,7 +704,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(4, 2, FALSE);
 
         /* auto jump to beginning of page */
-        dlg->auto_jump = gtk_check_button_new_with_label(_("Jump to beginning of page"));
+        dlg->auto_jump = gtk_check_button_new_with_mnemonic(_("_Jump to beginning of page"));
         gtk_table_attach(GTK_TABLE(table), dlg->auto_jump,
                          0, 2, 0, 1,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -709,7 +714,7 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->auto_jump);
         /* automatically flip pages */
-        dlg->page_flip = gtk_check_button_new_with_label(_("Automatically flip pages"));
+        dlg->page_flip = gtk_check_button_new_with_mnemonic(_("Automatically _flip pages"));
         gtk_table_attach(GTK_TABLE(table), dlg->page_flip,
                          0, 2, 1, 2,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -720,7 +725,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->page_flip);
 
         /* show previously visible part */
-        dlg->show_scroll_rect = gtk_check_button_new_with_label(_("Outline last visible part when scrolling"));
+        dlg->show_scroll_rect = gtk_check_button_new_with_mnemonic(_("Outline _last visible part when scrolling"));
         gtk_table_attach(GTK_TABLE(table), dlg->show_scroll_rect,
                          0, 2, 9, 10,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -734,7 +739,7 @@ ggv_prefs_dialog_new()
         adj = gtk_adjustment_new(0.0, 0.0, 1.0, 0.01, 0.1, 0.1);
         dlg->scroll_step = gtk_spin_button_new(GTK_ADJUSTMENT(adj),
                                                0.01, 2);
-        label = gtk_label_new(_("Amount of visible area to scroll"));  
+        label = gtk_label_new_with_mnemonic(_("Amount of _visible area to scroll"));  
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 2, 3,
                          GTK_SHRINK | GTK_FILL,
@@ -749,6 +754,7 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->scroll_step);
         gtk_widget_show(label);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->scroll_step);
 
         label = gtk_label_new(_("Navigation"));
         gtk_widget_show(label);
@@ -759,7 +765,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(4, 2, FALSE);
 
         /* interpreter */
-        label = gtk_label_new(_("Interpreter:"));
+        label = gtk_label_new_with_mnemonic(_("_Interpreter:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
@@ -778,8 +784,10 @@ ggv_prefs_dialog_new()
 	g_signal_connect(G_OBJECT(dlg->gs), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->gs);
-        /* interpreter */
-        label = gtk_label_new(_("Antialiasing:"));
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->gs);
+
+        /* antialiasing */
+        label = gtk_label_new_with_mnemonic(_("A_ntialiasing:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 1, 2,
@@ -798,8 +806,10 @@ ggv_prefs_dialog_new()
 	g_signal_connect(G_OBJECT(dlg->alpha_params), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->alpha_params);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->alpha_params);
+
         /* scan PDF command */
-        label = gtk_label_new(_("Convert PDF to PS:"));
+        label = gtk_label_new_with_mnemonic(_("Convert _PDF to PS:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 2, 3,
@@ -818,9 +828,10 @@ ggv_prefs_dialog_new()
 	g_signal_connect(G_OBJECT(dlg->convert_pdf), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->convert_pdf);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->convert_pdf);
 
 	/* unzip command: gzip */
-        label = gtk_label_new(_("Gzip:"));
+        label = gtk_label_new_with_mnemonic(_("_Gzip:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 3, 4,
@@ -839,9 +850,10 @@ ggv_prefs_dialog_new()
 	g_signal_connect(G_OBJECT(dlg->unzip), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	gtk_widget_show(dlg->unzip);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->unzip);
 
 	/* unzip command: bzip2 */
-        label = gtk_label_new(_("Bzip2:"));
+        label = gtk_label_new_with_mnemonic(_("_Bzip2:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 4, 5,
@@ -860,6 +872,7 @@ ggv_prefs_dialog_new()
 	g_signal_connect(G_OBJECT(dlg->unbzip2), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	gtk_widget_show(dlg->unbzip2);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->unbzip2);
 
         label = gtk_label_new(_("Ghostscript"));
         gtk_widget_show(label);
@@ -870,7 +883,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(1, 2, FALSE);
 
         /* print command */
-        label = gtk_label_new(_("Print command:"));
+        label = gtk_label_new_with_mnemonic(_("_Print command:"));
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
                          GTK_FILL,
@@ -888,6 +901,7 @@ ggv_prefs_dialog_new()
 	g_signal_connect(G_OBJECT(dlg->print), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->print);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->print);
 
         label = gtk_label_new(_("Printing"));
         gtk_widget_show(label);
