@@ -928,7 +928,7 @@ set_up_page (GtkGS *gs)
                             buf,
                             strlen(buf));
 
-        gdk_flush(); 
+        gdk_flush();
 }
 
 static void
@@ -1414,10 +1414,48 @@ check_pdf (GtkGS *gs)
 		g_free (cmd);
 
 		if ((system (cmdline) == 0)
-		    && ggv_file_readable (filename_dsc)
-		    && (ggv_file_length (filename_err) == 0)) {
+		    && ggv_file_readable (filename_dsc) ) {
+
 			/* success */
 			filename = gs->gs_filename_dsc = filename_dsc;
+			
+			if (ggv_file_length (filename_err) > 0) {
+				gchar *err_msg = " ";
+				GtkWidget *dialog;
+				FILE *err;
+				GdkColor color;
+
+				if ((err = fopen (filename_err, "r"))) {
+
+					/* print the content of the file to a message box */
+					while (fgets (buf, 1024, err))
+						err_msg = g_strconcat (err_msg,buf ,NULL);
+
+					/* FIXME The dialog is not yet set to modal, difficult to 
+					 * get the parent of the dialog box here 
+					 */ 
+
+					dialog = gtk_message_dialog_new (NULL ,
+									 GTK_DIALOG_MODAL,
+									 GTK_MESSAGE_WARNING,
+									 GTK_BUTTONS_OK,
+									 ("There was an error while scaning the file: %s \n%s"),
+									 gs->gs_filename,
+									 err_msg);
+
+					gdk_color_parse ("white", &color);
+					gtk_widget_modify_bg (GTK_WIDGET(dialog), GTK_STATE_NORMAL, &color);
+
+					g_signal_connect (G_OBJECT (dialog), "response",
+							  G_CALLBACK (gtk_widget_destroy),
+							  NULL);
+
+					gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+					gtk_widget_show (dialog);
+					g_free(err_msg);
+				}
+			}
+
 		} else {
 			/* report error */
 			g_snprintf (buf, 1024,
@@ -1948,7 +1986,7 @@ gtk_gs_goto_page (GtkGS *gs, gint page)
                    the last page of the file was displayed. In that
                    case, ggv restarts GS again and the first page is displayed.
                 */
-                if (page == gs->current_page && gs->changed)
+                if (page == gs->current_page && !gs->changed)
                         return TRUE;
 
                 if(!GTK_WIDGET_REALIZED(gs))
@@ -1985,7 +2023,7 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
         g_return_val_if_fail(GTK_IS_GS(gs), FALSE);
 
         if(new_pagesize == -1) {
-                if(gs->default_size >= 0)
+                if(gs->default_size > 0)
                         new_pagesize = gs->default_size;
                 if (!gs->override_size && gs->doc) {
                         /* If we have a document:
@@ -2018,12 +2056,8 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
         }
 
         /* Compute bounding box */
-        if (!gs->doc) {
-                new_llx = new_lly = 0;
-                new_urx = papersizes[new_pagesize].width;
-                new_ury = papersizes[new_pagesize].height;
-        }
-        else if ((gs->doc->epsf && !gs->override_size) || new_pagesize == -1) { /* epsf or bbox */
+        if (gs->doc &&
+            ((gs->doc->epsf && !gs->override_size) || new_pagesize == -1)) { /* epsf or bbox */
                 if((pageid >= 0) &&
                    (gs->doc->pages) &&
                    (gs->doc->pages[pageid].boundingbox[URX] > gs->doc->pages[pageid].boundingbox[LLX]) &&
@@ -2042,11 +2076,12 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
                         new_urx = gs->doc->boundingbox[URX];
                         new_ury = gs->doc->boundingbox[URY];
                 }
-                new_pagesize = gs->default_size;
         }
         else {
+                if(new_pagesize < 0)
+                        new_pagesize = gs->default_size;
                 new_llx = new_lly = 0;
-                if (!gs->override_size && gs->doc->size &&
+                if (gs->doc && !gs->override_size && gs->doc->size &&
                     (new_pagesize < gs->doc->numsizes)) {
                         new_urx = gs->doc->size[new_pagesize].width;
                         new_ury = gs->doc->size[new_pagesize].height;
@@ -2057,12 +2092,12 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
         }
 
         if(new_urx <= new_llx)
-                new_urx = papersizes[8].width;
+                new_urx = papersizes[12].width;
         if(new_ury <= new_lly)
-                new_ury = papersizes[8].height;
+                new_ury = papersizes[12].height;
 
         /* If bounding box changed, setup for new size. */
-                /* gtk_gs_disable_interpreter (gs); */
+        /* gtk_gs_disable_interpreter (gs); */
         if ((new_llx != gs->llx) || (new_lly != gs->lly) ||
             (new_urx != gs->urx) || (new_ury != gs->ury)) {
                 gs->llx = new_llx;
@@ -2237,9 +2272,15 @@ gtk_gs_get_orientation(GtkGS *gs)
 	g_return_val_if_fail(gs != NULL, -1);
 	g_return_val_if_fail(GTK_IS_GS(gs), -1);
 
-        if(gs->doc && gs->structured_doc) {
-                if(gs->doc->pages[MAX(gs->current_page, 0)].orientation != GTK_GS_ORIENTATION_NONE)
-                        gs->real_orientation = gs->doc->pages[MAX(gs->current_page, 0)].orientation;
+        if(gs->doc) {
+                if(gs->structured_doc) {
+                        if(gs->doc->pages[MAX(gs->current_page, 0)].orientation != GTK_GS_ORIENTATION_NONE)
+                                gs->real_orientation = gs->doc->pages[MAX(gs->current_page, 0)].orientation;
+                        else gs->real_orientation = gs->doc->default_page_orientation;
+                }
+        
+                if(gs->real_orientation == GTK_GS_ORIENTATION_NONE)
+                        gs->real_orientation = gs->doc->orientation;
         }
 
         if (gs->override_orientation ||
@@ -2380,7 +2421,7 @@ gtk_gs_get_document_page_label(GtkGS *widget, int page)
 }
 
 gint
-gtk_gs_get_size_index(gchar *string, GtkGSPaperSize *size)
+gtk_gs_get_size_index(const gchar *string, GtkGSPaperSize *size)
 {
         guint idx = 0;
 
