@@ -219,7 +219,7 @@ void          gtk_gs_set_zoom_mode(GtkGS *gs, GtkGSZoomMode zoom_mode);
 GtkGSZoomMode gtk_gs_get_zoom_mode(GtkGS *gs);
 
 /* utility functions */
-gint     gtk_gs_get_size_index(gchar *string, GtkGSPaperSize *size);
+gint     gtk_gs_get_size_index(const gchar *string, GtkGSPaperSize *size);
 
 gchar   *gtk_gs_get_postscript(GtkGS *gs, gint *pages);
 
